@@ -39,8 +39,11 @@ function (x, y, reference.grid = TRUE, main = "Title", ylab=NULL, xlab=NULL, xli
 
     plot(x~y, main = main, pch = symbolset, ylog = ylog, col=colorset, ...)
 
-    if(reference.grid)
+    if(reference.grid) {
         grid(col = elementcolor)
+        abline(h = 0, col = elementcolor)
+        abline(v = 0, col = elementcolor)
+    }
 }
 
 ###############################################################################
@@ -51,10 +54,13 @@ function (x, y, reference.grid = TRUE, main = "Title", ylab=NULL, xlab=NULL, xli
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.Scatter.R,v 1.3 2007/04/02 21:58:42 peter Exp $
+# $Id: chart.Scatter.R,v 1.4 2007/04/25 20:07:12 peter Exp $
 #
 ###############################################################################
 # $Log: chart.Scatter.R,v $
+# Revision 1.4  2007/04/25 20:07:12  peter
+# - added x-y axes
+#
 # Revision 1.3  2007/04/02 21:58:42  peter
 # - changed colorset default
 # - changed to use checkData
