@@ -1,5 +1,5 @@
 `charts.PerformanceSummary` <-
-function (R, rf = 0, main = NULL, method = "ModifiedVaR", width = 0, event.labels = NULL, ylog = FALSE, wealth.index = FALSE, gap = 12, ...)
+function (R, rf = 0, main = NULL, method = c("ModifiedVaR","VaR","StdDev"), width = 0, event.labels = NULL, ylog = FALSE, wealth.index = FALSE, gap = 12, begin=c("first","axis"), ...)
 { # @author Peter Carl
 
     # DESCRIPTION:
@@ -23,6 +23,7 @@ function (R, rf = 0, main = NULL, method = "ModifiedVaR", width = 0, event.label
     # A stack of three related timeseries line charts
 
     # FUNCTION:
+    begin = begin[1]
     x = checkData(R, method = "zoo")
     colnames = colnames(x)
     ncols = ncol(x)
@@ -39,7 +40,7 @@ function (R, rf = 0, main = NULL, method = "ModifiedVaR", width = 0, event.label
         wealth.index = TRUE
 
     # First, we lay out the graphic as a three row, one column format
-    plot.new()
+#    plot.new()
     layout(matrix(c(1,2,3)),height=c(2,1,1.3),width=1)
     # to see the resulting layout, use layout.show(3)
 
@@ -49,7 +50,7 @@ function (R, rf = 0, main = NULL, method = "ModifiedVaR", width = 0, event.label
 
     # The first row is the cumulative returns line plot
     par(mar=c(1,4,4,2))
-    chart.CumReturns(x, main = main, xaxis = FALSE, ylab = NULL, legend.loc = legend.loc, event.labels = event.labels, ylog = ylog, wealth.index = wealth.index, ...)
+    chart.CumReturns(x, main = main, xaxis = FALSE, ylab = NULL, legend.loc = legend.loc, event.labels = event.labels, ylog = ylog, wealth.index = wealth.index, begin = begin, ...)
 
     # The second row is the monthly returns bar plot
     par(mar=c(1,4,0,2))
@@ -75,10 +76,19 @@ function (R, rf = 0, main = NULL, method = "ModifiedVaR", width = 0, event.label
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: charts.PerformanceSummary.R,v 1.9 2007/04/09 12:31:27 brian Exp $
+# $Id: charts.PerformanceSummary.R,v 1.12 2007/06/29 15:52:25 peter Exp $
 #
 ###############################################################################
 # $Log: charts.PerformanceSummary.R,v $
+# Revision 1.12  2007/06/29 15:52:25  peter
+# - removed plot.new() that was causing two page pdf files
+#
+# Revision 1.11  2007/06/18 03:35:22  brian
+# - make method argument a list
+#
+# Revision 1.10  2007/04/30 12:56:05  peter
+# - changed 'method' to 'begin'
+#
 # Revision 1.9  2007/04/09 12:31:27  brian
 # - syntax and usage changes to pass R CMD check
 #
@@ -107,4 +117,4 @@ function (R, rf = 0, main = NULL, method = "ModifiedVaR", width = 0, event.label
 # - Initial Revision of packaged files to version control
 # Bug 890
 #
-###############################################################################
\ No newline at end of file
+###############################################################################
